#!/bin/bash
#
# Soluti Certificação Digital
# 
# Instalador Safenet Ubuntu
# Utilização: sudo ./install.sh
#                  ou
#             sudo bash install.sh
#


APT="/usr/bin/apt-get"
DPKG="/usr/bin/dpkg"

LOG="install.log"
ID=$(id -u)
ARCH=$(uname -m | sed 's/x86_//;s/i[3-6]86/32/')

function DetectaUbuntu {
 OS=$(awk '/DISTRIB_ID=/' /etc/*-release | sed 's/DISTRIB_ID=//' | tr '[:upper:]' '[:lower:]')
 if [ -f /etc/lsb-release -a ! -z "$OS" ]; then
  echo "0"
 else
  echo "1"
 fi
}

function SafenetInstallx86 {
 echo -e "\n\n########## Instalando Safenet x86\n\n" >> "$LOG"
 $DPKG -i ./x86/SafenetAuthenticationClient-8.3.34-0_i386.deb >> "$LOG" 2>&1
 echo "$?"
}

function SafenetInstallx64 {
 echo -e "\n\n########## Instalando Safenet x64\n\n" >> "$LOG"
 $DPKG -i ./x64/SafenetAuthenticationClient-8.3.34-0_amd64.deb >> "$LOG" 2>&1
 echo "$?"
}

function VerificaSafenet {
 $DPKG -l | grep safenetauthenticationclient | grep ^ii > /dev/null 2>&1
 echo "$?"
}

function Banner {
 echo -e "\n###################################"
 echo "# "
 echo -e "#   Soluti Certificação Digital "
 echo -e "#   Instalador Safenet Ubuntu "
 echo "# "
 echo -e "###################################\n"
}

function Suporte {
  echo "    Poderá entrar em contato pelos números:"
  echo "     * (062) 3999-6000 - Opção 2"
}

function RemoveLog {
 if [ -f $LOG ]; then
  rm -f "$LOG"
 fi
}

Banner
RemoveLog

if [ "$ID" -eq 0 ]; then
  if [ $(DetectaUbuntu) -eq 0 ]; then
    if [ "$ARCH" -eq 86 -o "$ARCH" -eq 32 ]; then
     if [ $(VerificaSafenet) -ne 0 ]; then
      echo "[+] Instalando pacote Safenet"
      if [ $(SafenetInstallx86) -ne 0 ]; then
       echo "    [+] Atualizando lista de repositórios..."
       echo -e "\n\n########## Atualizando repositórios\n\n" >> "$LOG"
       $APT update >> "$LOG" 2>&1

       echo "    [+] Instalando pacotes requeridos..."
       echo -e "\n\n########## Instalando pacotes requeridos\n\n" >> "$LOG"
       $APT -f install -y >> "$LOG" 2>&1
       $APT install libqt4-core libqt4-gui hal-info pcscd -y >> "$LOG" 2>&1
       $DPKG -i ./x86/hal-info_20091130-1_all.deb ./x86/libhal1_0.5.14-0ubuntu5_i386.deb ./x86/libhal-storage1_0.5.14-8ubuntu1_i386.deb >> "$LOG" 2>&1

       if [ $(SafenetInstallx86) -eq 0 ]; then
          echo "[+] Safenet x86 instalado com êxito!"
       else
          echo "    [-] Safenet não foi instalado "
          Suporte
          exit
       fi
     fi

     else
      echo "[+] Pacote Safenetx86 já está instalado"
      exit
     fi

    elif [ "$ARCH" -eq 64 ]; then

     if [ $(VerificaSafenet) -ne 0 ]; then
      echo "[+] Instalando pacote Safenet"
      if [ $(SafenetInstallx64) -eq 0 ]; then
        echo "[+] Safenet x64 instalado com êxito!"
        exit
      else
        echo "    [+] Atualizando lista de repositórios..."
       echo -e "\n\n########## Atualizando repositórios\n\n" >> "$LOG"
        $APT update >> "$LOG" 2>&1
        echo "    [+] Instalando pacotes requeridos..."
        echo -e "\n\n########## Instalando pacotes requeridos\n\n" >> "$LOG"
        $APT -f install -y >> "$LOG" 2>&1
        $APT install libqt4-core libqt4-gui hal-info -y >> "$LOG" 2>&1
        $DPKG -i ./x64/hal-info_20091130-1_all.deb ./x64/libhal1_0.5.14-0ubuntu5_amd64.deb ./x64/libhal-storage1_0.5.14-8ubuntu1_amd64.deb >> "$LOG" 2>&1

        if [ $(SafenetInstallx64) -eq 0 ]; then
          echo "[+] Safenet x64 instalado com êxito!"
        else
          echo "[-] Safenet não foi instalado"
          Suporte
          exit
        fi
      fi

     else
       echo "[+] Pacote Safenetx64 já está instalado"
       exit
     fi

    fi
  else
   echo "[-] Script deverá ser executado na distribuição Linux Ubuntu"
   exit
  fi

else
  echo "Execute o '$0' como root!"
  exit
fi
